Index: /issm/trunk/src/c/ProcessParamsx/ProcessParamsx.cpp
===================================================================
--- /issm/trunk/src/c/ProcessParamsx/ProcessParamsx.cpp	(revision 551)
+++ /issm/trunk/src/c/ProcessParamsx/ProcessParamsx.cpp	(revision 552)
@@ -34,5 +34,5 @@
 	double* p_g=NULL;
 	double* t_g=NULL;
-	double* melting_g=NULL;
+	double* m_g=NULL;
 	
 	/*control: */
@@ -176,11 +176,11 @@
 			parameters->FindParam((void*)&melting,"melting");
 
 			/*Now, from temperature and melting, build t_g and melting_g, correctly partitioned: */
 			t_g=(double*)xcalloc(numberofnodes,sizeof(double));
-			melting_g=(double*)xcalloc(numberofnodes,sizeof(double));
+			m_g=(double*)xcalloc(numberofnodes,sizeof(double));
 
 			for(i=0;i<numberofnodes;i++){
 				t_g[(int)(partition[i])]=temperature[i];
-				melting_g[(int)(partition[i])]=melting[i];
+				m_g[(int)(partition[i])]=melting[i];
 			}
 
@@ -192,6 +192,6 @@
 
 			count++;
-			param= new Param(count,"melting_g",DOUBLEVEC);
-			param->SetDoubleVec(melting_g,numberofnodes);
+			param= new Param(count,"m_g",DOUBLEVEC);
+			param->SetDoubleVec(m_g,numberofnodes);
 			parameters->AddObject(param);
 
@@ -221,5 +221,5 @@
 	xfree((void**)&p_g); 
 	xfree((void**)&t_g); 
-	xfree((void**)&melting_g); 
+	xfree((void**)&m_g); 
 
 }
@@ -176,11 +176,11 @@
 			parameters->FindParam((void*)&melting,"melting");
 
-			/*Now, from temperature and melting, build t_g and melting_g, correctly partitioned: */
+			/*Now, from temperature and melting, build t_g and m_g, correctly partitioned: */
 			t_g=(double*)xcalloc(numberofnodes,sizeof(double));
